@@ -8,12 +8,12 @@ use WWW::Discogs;
 
 my $discogs = WWW::Discogs->new(apikey => '5b4bea98ec');
 my $search = $discogs->search('Bill Callahan');
-for my $result (@{ $search->exactresults }) {
+for my $result ($search->exactresults) {
 	if ($result->{type} eq 'artist') {
 		my $artist = $discogs->artist($result->{title});
-		if ($artist->images) {
+		if (my @images = $artist->images) {
 			print $artist->name . "\n";
-			print $artist->images->[0]{uri} . "\n\n";
+			print $images[0]{uri} . "\n\n";
 		}
 	}
 }
