@@ -5,7 +5,7 @@ use warnings;
 
 =head1 NAME
 
-WWW::Discogs::Label
+WWW::Discogs::Label - get music label information and images
 
 =head1 METHODS
 
@@ -29,42 +29,42 @@ sub name {
 
 =head2 releases
 
-returns an arrayref of releases
+returns an list of releases
 
 =cut
 sub releases {
 	my $self = shift;
-	return $self->{releases}{release};
+	return @{ $self->{releases}{release} };
 }
 
 =head2 images
 
-Returns an arrayref of images
+Returns an list of images
 
 =cut
 sub images {
 	my $self = shift;
-	return $self->{images}{image};
+	return @{ $self->{images}{image} };
 }
 
 =head2 primary_images
 
-Returns an arrayref of the primary images
+Returns an list of the primary images
 
 =cut
 sub primary_images {
 	my $self = shift;
-	return [ grep {$_->{type} eq 'primary'} @{$self->{images}{image}} ];
+	return grep {$_->{type} eq 'primary'} @{$self->{images}{image}};
 }
 
 =head2 secondary_images
 
-returns an arrayref of the secondary images
+returns an list of the secondary images
 
 =cut
 sub secondary_images {
 	my $self = shift;
-	return [ grep {$_->{type} eq 'secondary'} @{$self->{images}{image}} ];
+	return grep {$_->{type} eq 'secondary'} @{$self->{images}{image}};
 }
 
 =head2 contactinfo
@@ -79,12 +79,12 @@ sub contactinfo {
 
 =head2 sublabels
 
-returns an arrayref of sublabel names
+returns an list of sublabel names
 
 =cut
 sub sublabels {
 	my $self = shift;
-	return [ keys %{$self->{sublabels}} ];
+	return keys %{$self->{sublabels}};
 }
 
 1;
